import numpy as np
import gurobipy as gu


material_ij = np.array([[2, 5], [6, 1], [0, 1]])

m, n = np.shape(material_ij)
irange = range(m)
jrange = range(n)

profit_j = [2, 4]
resources_i = [20, 15, 3.5]

# -----------------------------------------
# our first optimization model:

model = gu.Model("our first model")
xj = [model.addVar(vtype=gu.GRB.CONTINUOUS, lb=0) for j in jrange]
model.update()

for i in irange:
    model.addConstr(gu.quicksum(material_ij[i][j]*xj[j] for j in jrange) <= resources_i[i], name="res %.2f" %resources_i[i])

model.setObjective(gu.quicksum(profit_j[j]*xj[j] for j in jrange))
model.modelSense = gu.GRB.MAXIMIZE

model.setParam("OutputFlag", 0.0)
model.optimize()

# ----------------------------------

print("optimal solution: ")
for j in jrange:
    print("product %i: " %(j + 1), xj[j].x)

print("and we get: ", model.objVal)
print()
for c in model.getConstrs():
    print(c.ConstrName, "shadow price: ", c.pi, "\t - slack: ", c.Slack)

print("Hello world")
